@@ -12,6 +12,11 @@ import sipbuild
 import os
 import sys
 import shutil
+import re
+
+
+var_pattern = re.compile(
+    rb"(\s+::([a-zA-Z0-9_]+::)?[a-zA-Z0-9_]+\* a[0-9]+);$")
 
 
 class PyWpsRpcProject(sipbuild.Project):
@@ -77,8 +82,6 @@ class RpcApiBindings(sipbuild.Bindings):
         super().apply_user_defaults(tool)
 
     def generate(self):
-        self.tags.append("Module_%s" % self.name)
-
         buildable = super().generate()
 
         pch_file = os.path.join(buildable.build_dir, "stdafx.h")
@@ -89,13 +92,37 @@ class RpcApiBindings(sipbuild.Bindings):
                 f.write("#include <%s>\n" % pch)
 
             f.write("#include <wpsapiex.h>\n")
+            f.write("#include <string>\n")
             f.write("#include <vector>\n\n")
             f.write("#endif\n")
 
         buildable.headers.append(pch_file)
 
+        # asyncio seems no improves here
+        self._fix_uninited_vars(buildable.sources)
+
         return buildable
 
+    def _fix_uninited_vars(self, sources):
+        """ Try init the pointer argument
+        We need it because of using sipEventCollectingWrapper
+        """
+        # FIXME: this should be done by SIP
+        for src in sources:
+            tmp_file = src + "_tmp"
+            f = open(src, "rb")
+            f_tmp = open(tmp_file, "wb+")
+
+            for line in f:
+                m = var_pattern.match(line)
+                if m:
+                    line = m.group(1) + b' = nullptr;\n'
+                f_tmp.write(line)
+
+            f.close()
+            f_tmp.close()
+            os.rename(tmp_file, src)
+
 
 class RpcCommon(RpcApiBindings):
 
@@ -139,7 +166,8 @@ class RpcCommon(RpcApiBindings):
                 state = 1
             elif state == 1 and line == b'{\n':
                 f_out.write(line)
-                f_out.write(b"    BSTR *pBstr = reinterpret_cast<BSTR*>(ptr);\n")
+                f_out.write(
+                    b"    BSTR *pBstr = reinterpret_cast<BSTR*>(ptr);\n")
                 f_out.write(b"    if (*pBstr)\n")
                 f_out.write(b"        _SysFreeString(*pBstr);\n")
                 state = 2
@@ -236,7 +264,15 @@ class RpcApiBuilder(sipbuild.Builder):
             sipbuild.Option("qmake",
                             metavar="<FILE>",
                             help="Specify the qmake executable"))
+        options.append(
+            sipbuild.Option("clang",
+                            option_type=bool,
+                            help="Use clang to compile the project"))
 
+        options.append(
+            sipbuild.Option("libcxx",
+                            option_type=bool,
+                            help="Link libc++ when --clang specified"))
         return options
 
     def apply_user_defaults(self, tool):
@@ -321,8 +357,14 @@ class RpcApiBuilder(sipbuild.Builder):
 
         old_dir = os.getcwd()
         os.chdir(self.project.build_dir)
-        self.project.run_command(
-            [self.qmake, "-recursive", self.project.name + ".pro"], fatal=True)
+
+        args = [self.qmake, "-recursive", self.project.name + ".pro"]
+        if self.clang:
+            if self.libcxx:
+                args.extend(["-spec", "linux-clang-libc++"])
+            else:
+                args.extend(["-spec", "linux-clang"])
+        self.project.run_command(args, fatal=True)
 
         self.project.progress("Compiling the project")
         self._run_make()
@@ -341,7 +383,8 @@ class RpcApiBuilder(sipbuild.Builder):
         with open(buildable.build_dir + "/" + buildable.target + ".pro", "w+") as f:
             f.write("TEMPLATE = lib\n")
             f.write("CONFIG += plugin no_plugin_name_prefix warn_off\n")
-            f.write("CONFIG += %s\n" % ("debug" if buildable.debug else "release"))
+            f.write("CONFIG += %s\n" %
+                    ("debug" if buildable.debug else "release"))
             f.write("CONFIG += c++11 precompile_header\n")
             f.write("%s\n" % ' '.join(buildable.builder_settings))
             f.write("TARGET = %s\n\n" % buildable.target)
@@ -363,13 +406,16 @@ class RpcApiBuilder(sipbuild.Builder):
 
             # hidden symbols
             with open(buildable.build_dir + "/" + buildable.target + ".exp", "w+") as exp:
-                exp.write("{ global: PyInit_%s; local: *; };" % buildable.target)
+                exp.write("{ global: PyInit_%s; local: *; };" %
+                          buildable.target)
 
-            f.write("QMAKE_LFLAGS += -Wl,--version-script=%s.exp\n" % buildable.target)
+            f.write("QMAKE_LFLAGS += -Wl,--version-script=%s.exp\n" %
+                    buildable.target)
             if not buildable.debug:
                 f.write("QMAKE_LFLAGS += -s\n")
             #f.write("QMAKE_LFLAGS_PLUGIN += -Wl,--no-undefined\n")
-            f.write("QMAKE_CXXFLAGS += -Wno-attributes -Wno-delete-non-virtual-dtor\n")
+            f.write(
+                "QMAKE_CXXFLAGS += -Wno-attributes -Wno-delete-non-virtual-dtor\n")
             f.write("QMAKE_CXXFLAGS += -Wno-delete-incomplete -Wno-unused-variable\n")
             f.write("QMAKE_RPATHDIR += $ORIGIN /opt/kingsoft/wps-office/office6\n")
             f.write("QMAKE_RPATHDIR += /usr/lib/office6\n\n")
@@ -385,7 +431,8 @@ class RpcApiBuilder(sipbuild.Builder):
             f.write("SOURCES = %s" % " \\\n\t".join(buildable.sources))
             f.write('\n\n')
 
-            f.write("target.path = %s\n" % (target_dir + "/" + self.project.name))
+            f.write("target.path = %s\n" %
+                    (target_dir + "/" + self.project.name))
             f.write("INSTALLS += target\n\n")
 
             # for dist-info
@@ -452,7 +499,8 @@ class RpcApiBuilder(sipbuild.Builder):
 
             f.write("SOURCES = %s\n\n" % " \\\n\t".join(sources))
 
-            f.write("target.path = %s\n" % (target_dir + "/" + self.project.name))
+            f.write("target.path = %s\n" %
+                    (target_dir + "/" + self.project.name))
             f.write("INSTALLS += target\n\n")
 
         sub_dirs.append("sip")
