@@ -21,7 +21,7 @@ class RpcException(Exception):
 
     def __str__(self):
         text = "RpcException: {}".format(self._text)
-        if not self._hr is None:
+        if self._hr is not None:
             text += " ({})".format(hex(self._hr & 0xffffffff))
 
         return text
@@ -38,14 +38,6 @@ class RpcMethod(object):
         self._method = method
         self._proxy = proxy
 
-        # AddRef to avoid Releasing before the method be called
-        # such as app.Documents.Add()
-        self._proxy.rpc_object.AddRef()
-
-    def __del__(self):
-        if self._proxy:
-            self._proxy.rpc_object.Release()
-
     def __call__(self, *args, **kwargs):
         ret = self._method(*args, **kwargs)
         if isinstance(ret, tuple):
@@ -78,7 +70,31 @@ class RpcMethod(object):
         return self._method.__doc__
 
 
+class RpcIter(object):
+    def __init__(self, rpc_object):
+        self._obj = rpc_object
+        # starts from 1 not 0
+        self._index = 1
+        self._count = len(rpc_object)
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        if self._index > self._count:
+            raise StopIteration
+
+        value = self._obj[self._index]
+        self._index += 1
+
+        return value
+
+
 class RpcProxy(object):
+    """ Deprecated
+    use RpcProxy only if you want to deduce the HRESULT
+    """
+
     __slots__ = ["_object", "_use_exception", "_last_hr"]
 
     def __init__(self, obj, use_exception=False):
@@ -98,49 +114,49 @@ class RpcProxy(object):
                 _check_iunknown(obj[1])
                 self._object = obj[1]
             elif use_exception:
-                raise RpcException("Can't create proxy due to the previous call failed.", obj[0])
+                raise RpcException(
+                    "Can't create proxy due to the previous call failed.", obj[0])
         else:
             _check_iunknown(obj)
             self._object = obj
 
         self._use_exception = use_exception
 
-    def __del__(self):
-        if self._object:
-            self._object.Release()
-
     def __getattr__(self, name):
-        if name.startswith("_"):
-            return getattr(self._object, name)
-
-        if hasattr(self._object, name):
-            return RpcMethod(getattr(self._object, name), self)
-
-        hr, value = getattr(self._object, "get_" + name)()
-        if hr != S_OK:
-            if self._use_exception:
-                raise RpcException("Call '{}.get_{}()' failed.".format(
-                    self._object.__class__.__name__, name), hr)
-            value = None
+        value = getattr(self._object, name)
+        if isinstance(value, BuiltinFunctionType):
+            return RpcMethod(value, self)
         elif isinstance(value, IUnknown):
             value = RpcProxy(value, self._use_exception)
 
-        self._last_hr = hr
-
+        self._last_hr = S_OK
         return value
 
     def __setattr__(self, name, value):
         if name in self.__slots__ or name in ("use_exception", "last_error", "rpc_object"):
             super().__setattr__(name, value)
         else:
-            hr = getattr(self._object, "put_" + name)(value)
-            if hr != S_OK and self._use_exception:
-                raise RpcException("Call '{}.put_{}({})' failed.".format(
-                    self._object.__class__.__name__, name, value), hr)
-            self._last_hr = hr
+            setattr(self._object, name, value)
+            self._last_hr = S_OK
 
     def __bool__(self):
-        return not self._object is None
+        return self._object is not None
+
+    def __len__(self):
+        return len(self._object)
+
+    def __getitem__(self, index):
+        item = self._object.__getitem__(index)
+        if isinstance(item, IUnknown):
+            item = RpcProxy(item, self._use_exception)
+
+        return item
+
+    def __iter__(self):
+        if hasattr(self._object, "__iter__"):
+            return iter(self._object)
+
+        return RpcIter(self)
 
     @property
     def rpc_object(self):
