@@ -3,10 +3,11 @@
 import sys
 import os
 
-sys.path.append(os.path.dirname(os.path.realpath(__file__)) + "/../build")
+sys.path.insert(0, os.path.dirname(os.path.realpath(__file__)) + "/../build")
 
 from pywpsrpc.rpcetapi import etapi
 from pywpsrpc import (rpcetapi, common)
+from pywpsrpc.utils import RpcIter
 
 
 def check_call(funcName, hr, value=None):
@@ -35,6 +36,16 @@ def test():
     hr, workbook = workbooks.Add()
     check_call("workbooks.Add", hr, workbook)
 
+    props = workbook.CustomDocumentProperties
+    print("Doc Props:")
+    for prop in RpcIter(props):
+        print("\t %s: %s" % (prop.Name, prop.Value))
+
+    props = workbook.BuiltinDocumentProperties
+    print("Builtin Props:")
+    for prop in RpcIter(props):
+        print("\t %s: %s" % (prop.Name, prop.Value))
+
     hr = workbook.Close()
     check_call("workbook.Close", hr)
 
